@@ -16,13 +16,15 @@
 #define LIBXMLXX_MINOR_VERSION 0
 
 /* Micro version number of libxml++. */
-#define LIBXMLXX_MICRO_VERSION 0
+#define LIBXMLXX_MICRO_VERSION 1
 
 #if defined (GLIBMM_DLL) && !defined (LIBXMLXX_STATIC)
   #ifdef LIBXMLPP_BUILD
     #define LIBXMLPP_API __declspec(dllexport)
-  #else
+  #elif !defined (__GNUC__)
     #define LIBXMLPP_API __declspec(dllimport)
+  #else /* don't dllimport classes/methods on GCC/MinGW */
+    #define LIBXMLPP_API
   #endif /* LIBXMLPP_BUILD - DLL */
 #else
   /* Build a static library or a non-Windows library*/
